==> hs-monad-control-0.3.1.4p1.tgz: lib/ghc/monad-control-0.3.1.4/register.sh <==
#!/bin/sh
echo 'name: monad-control
version: 0.3.1.4
id: monad-control-0.3.1.4-1d52a0e52c2ed35102613ba7d521f3af

license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
stability:
homepage: https://github.com/basvandijk/monad-control
package-url:
synopsis: Lift control operations, like exception catching, through monad transformers
description: This package defines the type class @MonadBaseControl@, a subset of
             @MonadBase@ into which generic control operations such as @catch@ can be
             lifted from @IO@ or any other base monad. Instances are based on monad
             transformers in @MonadTransControl@, which includes all standard monad
             transformers in the @transformers@ library except @ContT@.
             .
             See the @lifted-base@ package which uses @monad-control@ to lift @IO@
             operations from the @base@ library (like @catch@ or @bracket@) into any monad
             that is an instance of @MonadBase@ or @MonadBaseControl@.
             .
             Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
             library. The main difference is that this package provides CPS style operators
             and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
             simplify and speedup most definitions.
             .
             The following @criterion@ based benchmark shows that @monad-control@ is on
             average about 99% faster than @monad-peel@:
             .
             @git clone <https://github.com/basvandijk/bench-monad-peel-control>@
category: Control
author: Bas van Dijk, Anders Kaseorg
pkgpath: devel/hs-monad-control
exposed: True
exposed-modules: Control.Monad.Trans.Control
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/monad-control-0.3.1.4
library-dirs: /usr/local/lib/ghc/monad-control-0.3.1.4
hs-libraries: HSmonad-control-0.3.1.4
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         base-unicode-symbols-0.2.2.4-5e2b84bb0750865af1276498a03dd32a
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
         transformers-base-0.4.1-9023dccd35c525f9deca7e00af9540a5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-monad-control-0.3.1.4/html/monad-control.haddock
haddock-html: /usr/local/share/doc/hs-monad-control-0.3.1.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-monad-control-0.3.2.3.tgz: lib/ghc/monad-control-0.3.2.3/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-monad-control-0.3.2.3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: monad-control
version: 0.3.2.3
id: monad-control-0.3.2.3-00e9746047757fb9d75d5c7c5b946efb

license: BSD3
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
stability:
homepage: https://github.com/basvandijk/monad-control
package-url:
synopsis: Lift control operations, like exception catching, through monad transformers
description: This package defines the type class @MonadBaseControl@, a subset of
             @MonadBase@ into which generic control operations such as @catch@ can be
             lifted from @IO@ or any other base monad. Instances are based on monad
             transformers in @MonadTransControl@, which includes all standard monad
             transformers in the @transformers@ library except @ContT@.
             .
             See the @lifted-base@ package which uses @monad-control@ to lift @IO@
             operations from the @base@ library (like @catch@ or @bracket@) into any monad
             that is an instance of @MonadBase@ or @MonadBaseControl@.
             .
             Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
             library. The main difference is that this package provides CPS style operators
             and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
             simplify and speedup most definitions.
category: Control
author: Bas van Dijk, Anders Kaseorg
pkgpath: devel/hs-monad-control
exposed: True
exposed-modules: Control.Monad.Trans.Control
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/monad-control-0.3.2.3
library-dirs: /usr/local/lib/ghc/monad-control-0.3.2.3
hs-libraries: HSmonad-control-0.3.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         base-unicode-symbols-0.2.2.4-177f6d9b65cf26b5cd7f7894f662a5a3
         transformers-0.3.0.0-6458c21515cab7c1cf21e53141557a1c
         transformers-base-0.4.1-37efec07d48ea648ba6fa660d35527d5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-monad-control-0.3.2.3/html/monad-control.haddock
haddock-html: /usr/local/share/doc/hs-monad-control-0.3.2.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
